.. sarpy documentation master file

Welcome to sarpy's documentation!
=================================

.. toctree::
    :maxdepth: 3
    :caption: Contents:

    examples/index
    utils/index
    io/index
    geometry/index
    processing/index
    visualization/index
    annotation/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
